@@ -97,6 +97,9 @@ def load_area_from_string(area_strs, *regions):
     Like :func:`~pyresample.area_config.load_area`, but load from string
     directly.
 
+    For the opposite (i.e. to create a YAML string from an area), use
+    :meth:`~pyresample.geometry.AreaDefinition.dump`.
+
     Parameters
     ----------
     area_strs : str or List[str]
@@ -477,7 +480,8 @@ def create_area_def(area_id, projection, width=None, height=None, area_extent=No
         p = Proj(crs, preserve_units=True)
     except (RuntimeError, CRSError):
         # Assume that an invalid projection will be "fixed" by a dynamic area definition later
-        return _make_area(area_id, description, proj_id, projection, shape, area_extent, **kwargs)
+        return _make_area(area_id, description, proj_id, projection, shape, area_extent,
+                          resolution=resolution, **kwargs)
 
     # If no units are provided, try to get units used in proj_dict. If still none are provided, use meters.
     if units is None:
